@@ -7,6 +7,7 @@ number and original statement are printed for the user to debug.
 """
 
 from ..exceptions import PyBELWarning
+from ..utils import ensure_quotes
 
 
 class BELParserWarning(PyBELWarning):
@@ -379,7 +380,7 @@ class InvalidEntity(BELParserWarning):
         self.name = name
 
     def __str__(self):
-        return '{}:{} should not be coded as an entity'.format(self.namespace, self.name)
+        return '{}:{} should not be coded as an entity'.format(self.namespace, ensure_quotes(self.name))
 
 
 class InvalidFunctionSemantic(BELParserWarning):
@@ -389,8 +390,7 @@ class InvalidFunctionSemantic(BELParserWarning):
     """
 
     def __init__(self, line_number, line, position, func, namespace, name, allowed_functions):
-        super(InvalidFunctionSemantic, self).__init__(line_number, line, position, func, namespace, name,
-                                                      allowed_functions)
+        super().__init__(line_number, line, position, func, namespace, name, allowed_functions)
         self.func = func
         self.namespace = namespace
         self.name = name
@@ -400,19 +400,6 @@ class InvalidFunctionSemantic(BELParserWarning):
         return "{} {}:{} should be encoded as one of: {}".format(
             self.func,
             self.namespace,
-            self.name,
-            ', '.join(self.allowed_functions)
+            ensure_quotes(self.name),
+            ', '.join(self.allowed_functions),
         )
-
-
-class RelabelWarning(BELParserWarning):
-    """Raised when a node is relabeled."""
-
-    def __init__(self, line_number, line, position, node, old_label, new_label):
-        super(RelabelWarning, self).__init__(line_number, line, position, node, old_label, new_label)
-        self.node = node
-        self.old_label = old_label
-        self.new_label = new_label
-
-    def __str__(self):
-        return 'Tried to relabel {} from {} to {}'.format(self.node, self.old_label, self.new_label)
