@@ -3,7 +3,7 @@
 """Pre-defined predicates for nodes."""
 
 from functools import wraps
-from typing import Callable, Iterable
+from typing import Callable, Iterable, Type
 
 from .node_predicate_builders import function_inclusion_filter_builder
 from .typing import NodePredicate
@@ -11,9 +11,9 @@ from .utils import part_has_modifier
 from ..graph import BELGraph
 from ...constants import (
     ABUNDANCE, ACTIVITY, CAUSAL_RELATIONS, DEGRADATION, FRAGMENT, FUNCTION, GENE, GMOD, HGVS, KIND, MIRNA, OBJECT,
-    PATHOLOGY, PMOD, PROTEIN, RELATION, RNA, SUBJECT, TRANSLOCATION, VARIANTS,
+    PART_OF, PATHOLOGY, PMOD, PROTEIN, RELATION, RNA, SUBJECT, TRANSLOCATION, VARIANTS,
 )
-from ...dsl import BaseEntity
+from ...dsl import BaseEntity, ListAbundance
 
 __all__ = [
     'node_predicate',
@@ -38,14 +38,15 @@ __all__ = [
     'is_causal_source',
     'is_causal_sink',
     'is_causal_central',
+    'is_isolated_list_abundance',
 ]
 
 
 def node_predicate(f: Callable[[BaseEntity], bool]) -> NodePredicate:  # noqa: D202
-    """Tag a node predicate that takes a dictionary to also accept a pair of (BELGraph, tuple).
+    """Tag a node predicate that takes a dictionary to also accept a pair of (BELGraph, node).
 
-    Apply this as a decorator to a function that takes a single argument, a PyBEL node data dictionary, to make
-    sure that it can also accept a pair of arguments, a BELGraph and a PyBEL node tuple as well.
+    Apply this as a decorator to a function that takes a single argument, a PyBEL node, to make
+    sure that it can also accept a pair of arguments, a BELGraph and a PyBEL node as well.
     """
 
     @wraps(f)
@@ -254,3 +255,15 @@ def is_causal_central(graph: BELGraph, node: BaseEntity) -> bool:
     - Does have causal out edge(s)
     """
     return has_causal_in_edges(graph, node) and has_causal_out_edges(graph, node)
+
+
+def is_isolated_list_abundance(graph: BELGraph, node: BaseEntity, cls: Type[ListAbundance] = ListAbundance) -> bool:
+    """Return if the node is a list abundance but has no qualified edges."""
+    return (
+        isinstance(node, cls)
+        and 0 == graph.out_degree(node)
+        and all(
+            data[RELATION] == PART_OF
+            for _, __, data in graph.in_edges(node, data=True)
+        )
+    )
