@@ -2,6 +2,7 @@
 
 """Utilities for functions for collapsing nodes."""
 
+import itertools as itt
 from typing import Mapping, Set
 
 from ...filters import filter_edges
@@ -14,6 +15,7 @@ __all__ = [
     'collapse_pair',
     'collapse_nodes',
     'collapse_all_variants',
+    'surviors_are_inconsistent',
 ]
 
 
@@ -38,16 +40,16 @@ def collapse_pair(graph, survivor: BaseEntity, victim: BaseEntity) -> None:
     :param victim: The BEL node to collapse into the surviving node
     """
     graph.add_edges_from(
-        (survivor, successor, key, data)
-        for _, successor, key, data in graph.out_edges(victim, keys=True, data=True)
+        (survivor, successor, key, edge_data)
+        for _, successor, key, edge_data in graph.out_edges(victim, keys=True, data=True)
         if successor != survivor
-    )
+    )  # FIXME key should be updated
 
     graph.add_edges_from(
         (predecessor, survivor, key, data)
         for predecessor, _, key, data in graph.in_edges(victim, keys=True, data=True)
         if predecessor != survivor
-    )
+    )  # FIXME key should be updated
 
     graph.remove_node(victim)
 
@@ -62,6 +64,10 @@ def collapse_nodes(graph, survivor_mapping: Mapping[BaseEntity, Set[BaseEntity]]
     :param survivor_mapping: A dictionary with survivors as their keys, and iterables of the corresponding victims as
      values.
     """
+    inconsistencies = surviors_are_inconsistent(survivor_mapping)
+    if inconsistencies:
+        raise ValueError('survivor mapping is inconsistent: {}'.format(inconsistencies))
+
     for survivor, victims in survivor_mapping.items():
         for victim in victims:
             collapse_pair(graph, survivor=survivor, victim=victim)
@@ -69,6 +75,15 @@ def collapse_nodes(graph, survivor_mapping: Mapping[BaseEntity, Set[BaseEntity]]
     _remove_self_edges(graph)
 
 
+def surviors_are_inconsistent(survivor_mapping: Mapping[BaseEntity, Set[BaseEntity]]) -> Set[BaseEntity]:
+    """Check that there's no transitive shit going on."""
+    victim_mapping = set()
+    for victim in itt.chain.from_iterable(survivor_mapping.values()):
+        if victim in survivor_mapping:
+            victim_mapping.add(victim)
+    return victim_mapping
+
+
 @in_place_transformation
 def collapse_all_variants(graph) -> None:
     """Collapse all genes', RNAs', miRNAs', and proteins' variants to their parents.
