@@ -6,7 +6,4 @@ from . import deletion, protein_rna_origins
 from .deletion import *
 from .protein_rna_origins import *
 
-__all__ = (
-    protein_rna_origins.__all__ +
-    deletion.__all__
-)
+__all__ = protein_rna_origins.__all__ + deletion.__all__
