@@ -5,7 +5,7 @@
 import logging
 
 from ..pipeline import in_place_transformation
-from ...constants import ANNOTATIONS, CITATION, CITATION_REFERENCE, CITATION_TYPE
+from ...constants import ANNOTATIONS, CITATION, CITATION_DB, CITATION_IDENTIFIER
 
 __all__ = [
     'strip_annotations',
@@ -14,11 +14,11 @@ __all__ = [
     'remove_citation_metadata',
 ]
 
-log = logging.getLogger(__name__)
+logger = logging.getLogger(__name__)
 
 
 @in_place_transformation
-def strip_annotations(graph):
+def strip_annotations(graph) -> None:
     """Strip all the annotations from a BEL graph.
 
     :param pybel.BELGraph graph: A BEL graph
@@ -29,14 +29,15 @@ def strip_annotations(graph):
 
 
 @in_place_transformation
-def add_annotation_value(graph, annotation, value):
+def add_annotation_value(graph, annotation: str, value: str, strict: bool = True) -> None:
     """Add the given annotation/value pair to all qualified edges.
 
     :param pybel.BELGraph graph:
-    :param str annotation:
-    :param str value:
+    :param annotation:
+    :param value:
+    :param strict: Should the function ensure the annotation has already been defined?
     """
-    if annotation not in graph.defined_annotation_keywords:
+    if strict and annotation not in graph.defined_annotation_keywords:
         raise ValueError('annotation not defined: {}'.format(annotation))
 
     for u, v, k in graph.edges(keys=True):
@@ -50,15 +51,15 @@ def add_annotation_value(graph, annotation, value):
 
 
 @in_place_transformation
-def remove_annotation_value(graph, annotation, value):
+def remove_annotation_value(graph, annotation: str, value: str) -> None:
     """Remove the given annotation/value pair to all qualified edges.
 
     :param pybel.BELGraph graph:
-    :param str annotation:
-    :param str value:
+    :param annotation:
+    :param value:
     """
     if annotation not in graph.defined_annotation_keywords:
-        log.warning('annotation was not defined: %s', annotation)
+        logger.warning('annotation was not defined: %s', annotation)
         return
 
     for u, v, k in graph.edges(keys=True):
@@ -74,11 +75,11 @@ def remove_annotation_value(graph, annotation, value):
         del graph[u][v][k][ANNOTATIONS][annotation][value]
 
 
-_CITATION_KEEP_KEYS = {CITATION_REFERENCE, CITATION_TYPE}
+_CITATION_KEEP_KEYS = {CITATION_IDENTIFIER, CITATION_DB}
 
 
 @in_place_transformation
-def remove_citation_metadata(graph):
+def remove_citation_metadata(graph) -> None:
     """Remove the metadata associated with a citation.
 
     Best practice is to add this information programmatically.
