@@ -3,9 +3,14 @@
 """Summary functions for edges in BEL graphs."""
 
 from collections import Counter, defaultdict
+from random import choice
+from typing import Iterable, Mapping, Set, Tuple
 
 from ..filters.edge_predicates import edge_has_annotation
+from ...canonicalize import edge_to_bel
 from ...constants import ANNOTATIONS, RELATION
+from ...dsl import BaseEntity
+from ...utils import CanonicalEdge, canonicalize_edge
 
 __all__ = [
     'iter_annotation_value_pairs',
@@ -17,14 +22,14 @@ __all__ = [
     'count_annotations',
     'get_unused_annotations',
     'get_unused_list_annotation_values',
+    'get_metaedge_to_key',
 ]
 
 
-def iter_annotation_value_pairs(graph):
+def iter_annotation_value_pairs(graph) -> Iterable[Tuple[str, str]]:
     """Iterate over the key/value pairs, with duplicates, for each annotation used in a BEL graph.
 
     :param pybel.BELGraph graph: A BEL graph
-    :rtype: iter[tuple[str,str]]
     """
     return (
         (key, value)
@@ -35,12 +40,11 @@ def iter_annotation_value_pairs(graph):
     )
 
 
-def iter_annotation_values(graph, annotation):
+def iter_annotation_values(graph, annotation: str) -> Iterable[str]:
     """Iterate over all of the values for an annotation used in the graph.
 
     :param pybel.BELGraph graph: A BEL graph
     :param str annotation: The annotation to grab
-    :rtype: iter[str]
     """
     return (
         value
@@ -62,33 +66,30 @@ def _group_dict_set(iterator):
     return dict(d)
 
 
-def get_annotation_values_by_annotation(graph):
+def get_annotation_values_by_annotation(graph) -> Mapping[str, Set[str]]:
     """Get the set of values for each annotation used in a BEL graph.
 
     :param pybel.BELGraph graph: A BEL graph
     :return: A dictionary of {annotation key: set of annotation values}
-    :rtype: dict[str, set[str]]
     """
     return _group_dict_set(iter_annotation_value_pairs(graph))
 
 
-def get_annotation_values(graph, annotation):
+def get_annotation_values(graph, annotation: str) -> Set[str]:
     """Get all values for the given annotation.
 
     :param pybel.BELGraph graph: A BEL graph
-    :param str annotation: The annotation to summarize
+    :param annotation: The annotation to summarize
     :return: A set of all annotation values
-    :rtype: set[str]
     """
     return set(iter_annotation_values(graph, annotation))
 
 
-def count_relations(graph):
+def count_relations(graph) -> Counter:
     """Return a histogram over all relationships in a graph.
 
     :param pybel.BELGraph graph: A BEL graph
     :return: A Counter from {relation type: frequency}
-    :rtype: collections.Counter
     """
     return Counter(
         data[RELATION]
@@ -96,41 +97,37 @@ def count_relations(graph):
     )
 
 
-def get_unused_annotations(graph):
+def get_unused_annotations(graph) -> Set[str]:
     """Get the set of all annotations that are defined in a graph, but are never used.
 
     :param pybel.BELGraph graph: A BEL graph
     :return: A set of annotations
-    :rtype: set[str]
     """
     return graph.defined_annotation_keywords - get_annotations(graph)
 
 
-def get_annotations(graph):
+def get_annotations(graph) -> Set[str]:
     """Get the set of annotations used in the graph.
 
     :param pybel.BELGraph graph: A BEL graph
     :return: A set of annotation keys
-    :rtype: set[str]
     """
     return set(_annotation_iter_helper(graph))
 
 
-def count_annotations(graph):
+def count_annotations(graph) -> Counter:
     """Count how many times each annotation is used in the graph.
 
     :param pybel.BELGraph graph: A BEL graph
     :return: A Counter from {annotation key: frequency}
-    :rtype: collections.Counter
     """
     return Counter(_annotation_iter_helper(graph))
 
 
-def _annotation_iter_helper(graph):
+def _annotation_iter_helper(graph) -> Iterable[str]:
     """Iterate over the annotation keys.
 
-    :type graph: pybel.BELGraph
-    :rtype: iter[str]
+    :param pybel.BELGraph graph: A BEL graph
     """
     return (
         key
@@ -140,12 +137,11 @@ def _annotation_iter_helper(graph):
     )
 
 
-def get_unused_list_annotation_values(graph):
+def get_unused_list_annotation_values(graph) -> Mapping[str, Set[str]]:
     """Get all of the unused values for list annotations.
 
     :param pybel.BELGraph graph: A BEL graph
     :return: A dictionary of {str annotation: set of str values that aren't used}
-    :rtype: dict[str,set[str]]
     """
     result = {}
     for annotation, values in graph.annotation_list.items():
@@ -154,3 +150,21 @@ def get_unused_list_annotation_values(graph):
             continue
         result[annotation] = set(values) - used_values
     return result
+
+
+def get_metaedge_to_key(graph) -> Mapping[CanonicalEdge, Set[Tuple[BaseEntity, BaseEntity, str]]]:
+    """Get all edge types."""
+    rv = defaultdict(set)
+    for u, v, k, d in graph.edges(keys=True, data=True):
+        rel, u_mod, v_mod = canonicalize_edge(d)
+        rv[u.__class__.__name__, u_mod, rel, v.__class__.__name__, v_mod].add((u, v, k))
+    return dict(rv)
+
+
+def iter_sample_metaedges(graph):
+    """Iterate sampled metaedges."""
+    for k, value in get_metaedge_to_key(graph).items():
+        u, v, key = choice(list(value))
+        d = graph[u][v][key]
+        bel = edge_to_bel(u, v, d, use_identifiers=True)
+        yield (u, v, key, d, *k, bel)
